@@ -1,5 +1,5 @@
 #!/usr/local/bin/perl							
-#$Id: populate_mailbox.pl,v 19991216.7 2002/08/23 13:29:49 dkernen Exp $									#
+#$Id: populate_mailbox.pl,v 19991216.8 2003/06/12 21:38:34 dkernen Exp $									#
 use Time::Local								;
 use FileHandle								;
 use File::Copy								;
@@ -232,8 +232,60 @@ return 		sprintf							(
 			$date[0]					)
 									;
 									}
-# $Id: populate_mailbox.pl,v 19991216.7 2002/08/23 13:29:49 dkernen Exp $
+
+
+=head1 AUTHOR 
+	
+David J. Kernen
+
+The Kernen Group, Inc.
+
+imap@kernengroup.com
+
+=head1 COPYRIGHT
+
+This example and Mail::IMAPClient are Copyright (c) 2003 
+by The Kernen Group, Inc. All rights reserved.
+
+This example is distributed with Mail::IMAPClient and 
+subject to the same licensing requirements as Mail::IMAPClient.
+
+imtest is a utility distributed with Cyrus IMAP server, 
+Copyright (c) 1994-2000 Carnegie Mellon University.  
+All rights reserved. 
+
+=cut
+
+# $Id: populate_mailbox.pl,v 19991216.8 2003/06/12 21:38:34 dkernen Exp $
 # $Log: populate_mailbox.pl,v $
+# Revision 19991216.8  2003/06/12 21:38:34  dkernen
+#
+# Preparing 2.2.8
+# Added Files: COPYRIGHT
+# Modified Files: Parse.grammar
+# Added Files: Makefile.old
+# 	Makefile.PL Todo sample.perldb
+# 	BodyStructure.pm
+# 	Parse.grammar Parse.pod
+#  	range.t
+#  	Thread.grammar
+#  	draft-crispin-imapv-17.txt rfc1731.txt rfc2060.txt rfc2062.txt
+#  	rfc2221.txt rfc2359.txt rfc2683.txt
+#
+# Revision 1.1  2003/06/12 21:38:16  dkernen
+#
+# Preparing 2.2.8
+# Added Files: COPYRIGHT
+# Modified Files: Parse.grammar
+# Added Files: Makefile.old
+# 	Makefile.PL Todo sample.perldb
+# 	BodyStructure.pm
+# 	Parse.grammar Parse.pod
+#  	range.t
+#  	Thread.grammar
+#  	draft-crispin-imapv-17.txt rfc1731.txt rfc2060.txt rfc2062.txt
+#  	rfc2221.txt rfc2359.txt rfc2683.txt
+#
 # Revision 19991216.7  2002/08/23 13:29:49  dkernen
 #
 # Modified Files: Changes IMAPClient.pm INSTALL MANIFEST Makefile Makefile.PL README Todo test.txt
